      PROGRAM HUGN
C     ------------
C
*
*
*    TO BE CITED AT ANY TIME OF USE:
*
*    J.~Bl\"umlein, V.~Ravindran,
*    ``Mellin moments of the next-to-next-to leading order coefficient functions for the
*    Drell-Yan process and hadronic Higgs-boson production,''
*    Nucl.\ Phys.\  {\bf B716 } (2005)  128-172.
*    [hep-ph/0501178].
*
*    J. Bl\"umlein
*    ``Analytic continuation of Mellin transforms up to two loop order,''
*    Comput.\ Phys.\ Commun.\  {\bf 133 } (2000)  76-104.
*    [hep-ph/0003100].
*
*
*     AIND etc.: Piessens, Angew. Informatik {\bf 9} (1973) 399
*

*---------------------------------
* This program inverts the following
* Mellin Moment=\int x^(N-1) F(x)
*---------------------------------
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 DIR,STA,SS,ZN,FF,FUNC,FUNC1
      COMMON /OFFS  / CP(26)
      COMMON /WGAUSS/ XL8(8),WL8(8),XL32(32),WL32(32)
      COMMON /EP/EPS
      COMMON /KM/KEY,MAX
      COMMON /FKNLL/  LL
      COMMON /PI    / PI
      COMMON /ZET2/ ZETA2
      COMMON /ZET3/ ZETA3
C------------------------------------
C     USER DEFINED PARAMETERS
C------------------------------------
      COMMON/VAR/XMH,XMUR,XMUF,XNF,NL
      COMMON/EXPT/MODH,MODP,RS
C------------------------------------
C     END USER DEFINED PARAMETERS
C------------------------------------
      DIMENSION ZINT(51)
      PI = 3.141592653589793238462643D0
C      CALL TIMEX(TT1)
C      WRITE(*,*) TT1
      CALL INVINI
      CALL INIC

      KEY=2
      MAX=10000
      EPS=1.0D-9
      IGAUSS = 32
      ZERO=0.0D0

C-------------------------------------------------
C     INPUT PARAMETERS FOR THE COMPUTATION
C-------------------------------------------------
C     MODH MODH=1 FOR SCALAR, 2 FOR PSEUDO SCALAR
      MODH=1

C     MODP LHC=1(14000), TEVETRON=2(2000)
      MODP=1

C     MACHINE: LHC OR TEVETRON
      RSLHC=14000.0D0
      RSTEV=2000.0D0

C     ROOT(S) AT LHC AND TEVETRON
C     ---------------------------
      IF(MODP.EQ.1) THEN
      RS=RSLHC
      ELSE
      RS=RSTEV
      ENDIF

      DO 225 NL=1,3
      XMH=125.0D0
      XMUF=125.0D0
      XMUR=125.0D0
      XNF=5.0D0

C     LO, NLO, NNLO
C     --------------
      IF (NL.EQ.1) THEN
      WRITE(*,*)'************LO**************'
      WRITE(*,*)
      ELSEIF (NL.EQ.2) THEN
      WRITE(*,*)'************NLO**************'
      WRITE(*,*)
      ELSEIF (NL.EQ.3) THEN
      WRITE(*,*)'************NNLO**************'
      WRITE(*,*)
      ENDIF

      X=XMH**2/RS/RS
C-------------------------------------------------
C     END OF INPUT PARAMETERS FOR THE COMPUTATION
C-------------------------------------------------

      F1=FUNO(X)

      CPAR=1.50D0

      IF(X.LE.0.7D0) RANGE=91.0D0
      IF(X.LE.0.7D0) RANGE=91.0D0
      IF(X.GT.0.7D0) RANGE=91.0D0
      IF(X.LE.0.7D0) INTE =20
      IF(X.GT.0.7D0) INTE =20
      IF(X.LE.0.7D0) PHI=3.0D0/4.0D0*PI
*      IF(X.GT.0.7D0) PHI=7.0D0/8.0D0*PI
      IF(X.GT.0.7D0) PHI=3.0D0/4.0D0*PI
*      IF(X.GT.0.98D0) PHI=19.0D0/20.0D0*PI
      DIR=DCMPLX(DCOS(PHI),DSIN(PHI))
      STA=DCMPLX(CPAR,ZERO)
      ST   =EXP(LOG(RANGE)/DBLE(INTE))
      ST0  =1.0D0
      ZINT(1)=ZERO
      DO 10 L=1,20
      ST0 =ST0*ST
      L1=L+1
      ZINT(L1)=ST0-1.0D0
10    CONTINUE
C
      SS=DCMPLX(ZERO,ZERO)
      XBL=LOG(X)
C
      DO 20 L=1,20
      A=ZINT(L)
      B=ZINT(L+1)
      DLI=(B-A)/2.0D0
      SLI=(B+A)/2.0D0
C
      IF(IGAUSS.EQ. 8) NM=8
      IF(IGAUSS.EQ.32) NM=32
      IF(IGAUSS.NE.8.AND.IGAUSS.NE.32) 
     &WRITE(6,*) '*** IGAUSS=',IGAUSS,
     &        '*** WRONG IN SR INVERSE, STOP'
      IF(IGAUSS.NE.8.AND.IGAUSS.NE.32) STOP
C
      DO 21 M=1,NM
      IF(IGAUSS.EQ. 8) W=WL8(M)
      IF(IGAUSS.EQ.32) W=WL32(M)
      IF(IGAUSS.EQ. 8) ZZ=XL8(M)
      IF(IGAUSS.EQ.32) ZZ=XL32(M)
      Z= DLI*ZZ+SLI
      ZN=STA+Z*DIR
      FF=FUNC(ZN)
      SS=SS+FF*DIR*EXP(-XBL*ZN)*W*DLI
21    CONTINUE
20    CONTINUE
      F=DIMAG(SS)/PI
      WRITE(6,1000) XMH,F
1000  FORMAT('XMH,CROSS=',D12.5,3X,D12.5)
225   CONTINUE

C      CALL TIMEX(TT2)
C      WRITE(*,*) TT2
C      TDIFF=TT2-TT1 
C      WRITE(*,*) TDIFF
      STOP
      END



      COMPLEX*16 FUNCTION FUNC(Z)
C     ---------------------------
      IMPLICIT COMPLEX*16 (A-H,O-Z)
      DOUBLE PRECISION XNF,XMUF,XMH,XMT,XMUR,LAMBDA,CA,CF,TF,
     & XMUR2,XMUF2,XMH2,XMT2,ALS,AS,TAUB,TAUB2,FTB,FTB2,FBTB,FBTB2,
     & PI,CB,CB2,GB,GB2,GF,FAC,RSLHC,RSTEV,RS
      DOUBLE PRECISION ALFAS1,ALFAS2,ALFAS3
      INTEGER NL,MODE,MODP,MODH
      COMMON/VAR/XMH,XMUR,XMUF,XNF,NL
      COMMON/EXPT/MODH,MODP,RS
      EXTERNAL ALFAS1,ALFAS2,ALFAS3

      PI = 3.141592653589793238462643D0
      GF=4541.680D0
      XMT=173.40D0
      CA=3.0D0
      CF=4.0D0/3.0D0
      TF=0.50D0

C     STRUCTURE FUNCTION AND LAMBDA
C     -----------------------------
      IF(NL.EQ.1) THEN
      MODE=9
      LAMBDA=0.1670D0
      ELSEIF (NL.EQ.2) THEN
      MODE=5
      LAMBDA=0.2390D0
      ELSEIF (NL.EQ.3) THEN
      MODE=1
      LAMBDA=0.1760D0
      ENDIF

C      WRITE(*,*)'NL,MODE,LAMBDA', NL,MODE,LAMBDA


C     COUPLING CONSTANTS
C     ------------------
      IF (NL.EQ.1) THEN
      ALPS=ALFAS1(XMUR,LAMBDA,XNF)
      ELSEIF (NL.EQ.2) THEN
      ALPS=ALFAS2(XMUR,LAMBDA,XNF)
      ELSEIF (NL.EQ.3) THEN
      ALPS=ALFAS3(XMUR,LAMBDA,XNF)
      ENDIF

C      WRITE(*,*)'NL,LAMBDA,ALPS', NL,LAMBDA,ALPS


      AS=ALPS/4.0D0/PI

      XMH2=XMH*XMH
      XMT2=XMT*XMT
      XMUR2=XMUR*XMUR
      XMUF2=XMUF*XMUF
      TAUB=4.0D0*XMT2/XMH2
      TAUB2=TAUB*TAUB
      IF (TAUB.GT.1) THEN
      FTB=DASIN(0.50D0*XMH/XMT)
      ENDIF
      FTB2=FTB*FTB

      IF (MODH.EQ.1) THEN
      FBTB=1.0D0+(1.0D0-TAUB)*FTB2
      ELSE
C      FBTB=FTB2*ACOT(BETA)
      FBTB=0.0D0
      ENDIF
      FBTB2=FBTB**2
C     CB FACTOR
C     ---------
      CB0=1.0D0
      CB1=AS*(5.0D0*CA-3.0D0*CF)
      CB2=AS**2*(27.0D0/2.0D0*CF**2-100.0D0/3.0D0*CA*CF
     #       +1063.0D0/36.0D0*CA*CA-4.0D0/3.0D0*CF*TF
     #       -5.0D0/6.0D0*CA*TF+(7.0D0*CA**2-11.0D0*CA*CF)
     #       *LOG(XMUR2/XMT2)+XNF*TF*(-5.0D0*CF-47.0D0/9.0D0*CA
     #       +8.0D0*CF*LOG(XMUR2/XMT2)))

      GB2=4.0D0*DSQRT(2.0D0)*AS**2*GF*TAUB2*FBTB2
      FAC=PI*GB2/8.0D0/(CA*CA-1.0D0)

      CALL COEFFHN(Z,XMH,XMUF,XNF,
     & Sgg0,Sgg1,Sgq1,Sqqb1,Sgg2Ca2,Sgg2CaTfnf,
     & Sgg2CfTfnf,Sgg2rest,
     & Sqg2Cf2,Sqg2CaCf,Sqg2CfTfnf,Sqg2rest,SqqCaCf2,SqqCf3,
     & SqqCf2,Sqqrest,SqqbCaCf2,SqqbCf3,SqqbCf2,SqqbCf2Tfnf,Sqqbrest,
     & Sq1qb2Cf2,Sq1qb2rest,Sq1q2Cf2,Sq1q2rest)

       Sgg2=CA**2*Sgg2Ca2+CA*TF*XNF*Sgg2CaTfnf
     #      +CF*TF*XNF*Sgg2CfTfnf+Sgg2rest
       Sgq2=CF**2*Sqg2Cf2+CA*CF*Sqg2CaCf
     #      +CF*TF*XNF*Sqg2CfTfnf+Sqg2rest
       Sqqb2=CA*CF**2*SqqbCaCf2+CF**3*SqqbCf3+CF**2*SqqbCf2
     #       +CF**2*TF*XNF*SqqbCf2Tfnf+Sqqbrest
       Sq1qb22=CF**2*Sq1qb2Cf2+Sq1qb2rest
       Sqq2=CA*CF**2*SqqCaCf2+CF**3*SqqCf3
     #       +CF**2*SqqCf2+Sqqrest
       Sq1q22=CF**2*Sq1q2Cf2+Sq1q2rest


      T1=Z+1.0D0
      CALL PARTON(T1,UN,DN,USN,DSN,STN,CHN,BOTN,TOPN,GLN)

      GGN=GLN*GLN
      GQN=2.0D0*GLN*(UN+USN+DN+DSN+2.0D0*(STN+CHN+BOTN))
      QQBN=2.0D0*(UN*USN+DN*DSN+STN*STN+CHN*CHN+BOTN*BOTN)
      Q1QB2N=UN*(DSN+STN+CHN+BOTN)+DN*(USN+STN+CHN+BOTN)
     &       +STN*(USN+DSN+CHN+BOTN)+CHN*(USN+DSN+STN+BOTN)
     &       +BOTN*(USN+DSN+STN+CHN)
     &       +USN*(DN+STN+CHN+BOTN)+DSN*(UN+STN+CHN+BOTN)
     &       +STN*(UN+DN+CHN+BOTN)+CHN*(UN+DN+STN+BOTN)
     &       +BOTN*(UN+DN+STN+CHN)

      QQN=UN*UN+DN*DN+STN*STN+CHN*CHN+BOTN*BOTN
      QBQBN=USN*USN+DSN*DSN+STN*STN+CHN*CHN+BOTN*BOTN
      Q1Q2N=UN*(DN+STN+CHN+BOTN)+DN*(UN+STN+CHN+BOTN)
     &       +STN*(UN+DN+CHN+BOTN)+CHN*(UN+DN+STN+BOTN)
     &       +BOTN*(UN+DN+STN+CHN) 
      QB1QB2N=USN*(DSN+STN+CHN+BOTN)+DSN*(USN+STN+CHN+BOTN)
     &       +STN*(USN+DSN+CHN+BOTN)+CHN*(USN+DSN+STN+BOTN)
     &       +BOTN*(USN+DSN+STN+CHN)

      F0=GGN*Sgg0
      F1=GGN*Sgg1+GQN*Sgq1+QQBN*Sqqb1
      F2=GGN*Sgg2+GQN*Sgq2
     &      +QQBN*Sqqb2+Q1QB2N*Sq1qb22
     &      +(QQN+QBQBN)*Sqq2+(Q1Q2N+QB1QB2N)*Sq1q22

      IF (NL.EQ.1) THEN
      FUNC=FAC*F0
      ELSEIF (NL.EQ.2) THEN
      FUNC=FAC*F0+FAC*AS*F1+2.0D0*CB1*FAC*F0
      ELSEIF (NL.EQ.3) THEN
      FUNC=FAC*F0+FAC*AS*F1+FAC*AS**2*F2
     #   +(CB1**2+2.0D0*CB2)*FAC*F0+2.0D0*CB1*(FAC*AS*F1)
      ENDIF

      RETURN
      END


      REAL*8 FUNCTION FUNO(X)
C     -----------------------
      IMPLICIT REAL*8 (A-H,O-Z)

      FUNO=1.0D0

      RETURN
      END



      SUBROUTINE INVINI
C     -----------------
C
      IMPLICIT REAL*8 (A-H,O-Z)
C
      COMMON /OFFS  / CP(26)
      COMMON /PI    / PI
      COMMON /ZET2/ ZETA2
      COMMON /ZET3/ ZETA3
      COMMON /WGAUSS/ XL8(8),WL8(8),XL32(32),WL32(32)
C
      DATA  PI/ 3.14159265358979323846D+0/
C                 1      2      3      4      5       6       7
      DATA CP/-0.7D0,-1.7D0,-0.8D0,-0.7D0,-0.7D0,-0.7D0,-0.7D0,
     &        -1.7D0,-1.7D0,-1.7D0,-1.7D0,-1.7D0,-1.7D0, 0.3D0,
     &        -0.7D0,-0.7D0,-1.7D0, 0.3D0, 0.3D0, 0.3D0, 0.2D0,
     &        -0.5D0, 0.5D0, 0.5D0,0.5D0,-2.8D0/
C
      DATA XL8/-0.960289856497536231684D+0,
     &         -0.796666477413626739592D+0,
     &         -0.525532409916328985818D+0,
     &         -0.183434642495649804939D+0,
     &          0.183434642495649804939D+0,
     &          0.525532409916328985818D+0,
     &          0.796666477413626739592D+0,
     &          0.960289856497536231684D+0/
C
      DATA WL8/ 0.101228536290376259163D+0,
     &          0.222381034453374470518D+0,
     &          0.313706645877887287348D+0,
     &          0.362683783378361982964D+0,
     &          0.362683783378361982964D+0,
     &          0.313706645877887287348D+0,
     &          0.222381034453374470518D+0,
     &          0.101228536290376259163D+0/
C
      DATA XL32/-0.997263861849481563545D+0,
     &          -0.985611511545268335400D+0,
     &          -0.964762255587506430774D+0,
     &          -0.934906075937739689171D+0,
     &          -0.896321155766052123965D+0,
     &          -0.849367613732569970134D+0,
     &          -0.794483795967942406963D+0,
     &          -0.732182118740289680387D+0,
     &          -0.663044266930215200975D+0,
     &          -0.587715757240762329041D+0,
     &          -0.506899908932229390024D+0,
     &          -0.421351276130635345364D+0,
     &          -0.331868602282127649780D+0,
     &          -0.239287362252137074545D+0,
     &          -0.144471961582796493485D+0,
     &          -0.483076656877383162348D-1,
     &           0.483076656877383162348D-1,
     &           0.144471961582796493485D+0,
     &           0.239287362252137074545D+0,
     &           0.331868602282127649780D+0,
     &           0.421351276130635345364D+0,
     &           0.506899908932229390024D+0,
     &           0.587715757240762329041D+0,
     &           0.663044266930215200975D+0,
     &           0.732182118740289680387D+0,
     &           0.794483795967942406963D+0,
     &           0.849367613732569970134D+0,
     &           0.896321155766052123965D+0,
     &           0.934906075937739689171D+0,
     &           0.964762255587506430774D+0,
     &           0.985611511545268335400D+0,
     &           0.997263861849481563545D+0/
C
      DATA WL32/0.701861000943074980416D-2,
     &          0.162743947308230037851D-1,
     &          0.253920653084367920322D-1,
     &          0.342738629139351946052D-1,
     &          0.428358980239763007216D-1,
     &          0.509980592613025930634D-1,
     &          0.586840934788972562042D-1,
     &          0.658222227761892440852D-1,
     &          0.723457941088502071174D-1,
     &          0.781938957870682705896D-1,
     &          0.833119242269464135758D-1,
     &          0.876520930044038163114D-1,
     &          0.911738786957638874594D-1,
     &          0.938443990808045654352D-1,
     &          0.956387200792748594152D-1,
     &          0.965400885147278005676D-1,
     &          0.965400885147278005676D-1,
     &          0.956387200792748594152D-1,
     &          0.938443990808045654352D-1,
     &          0.911738786957638874594D-1,
     &          0.876520930044038163114D-1,
     &          0.833119242269464135758D-1,
     &          0.781938957870682705896D-1,
     &          0.723457941088502071174D-1,
     &          0.658222227761892440852D-1,
     &          0.586840934788972562042D-1,
     &          0.509980592613025930634D-1,
     &          0.428358980239763007216D-1,
     &          0.342738629139351946052D-1,
     &          0.253920653084367920322D-1,
     &          0.162743947308230037851D-1,
     &          0.701861000943074980416D-2/
C
      ZETA2=PI**2/6.0D0
      ZETA3=1.20205690315959428540D+0
C     PHI=3.0D0/4.0D0*PI
      PHI=9.0D0/10.0D0*PI
C
      RETURN
      END
      SUBROUTINE INIC
C     ----------------
C************************************************************************
C
C     J. BLUEMLEIN:  01.10.1999 (1.00)
C
C************************************************************************
C
C---  INITIALIZE CONSTANTS
C
C************************************************************************
C
      IMPLICIT REAL*8 (A-H,O-Z)
C
      COMMON /PIZ/PI,ZETA2,ZETA3,ZLI4,D2
      COMMON /KM/KEY,MAX
C
      COMMON/ACCON1/ DL
      COMMON/ACCON2/ ZET2
      COMMON/ACCON3/ ZET3
      COMMON/ACCON4/ GE
      COMMON/ACCON5/ XLI4
      COMMON/IAPP  / IAPP
      COMMON/VAL   / ZERO,ONE
      COMMON/ACLOG1/ AK1(9)
      COMMON/ACLOG2/ AK2(10)
      COMMON/ACLOG3/ AK3(11)
      COMMON/ACLOG4/ BK1(9)
      COMMON/ACLOG5/ BK2(10)
      COMMON/ACLOG6/ CK1(12)
      COMMON/ACLOG7/ CK2(13)
      COMMON/ACLOG8/ CK3(10)
      COMMON/ACLOG9/ CK4(13)
      COMMON/ACLG10/ CK5(9)
      COMMON/ACLG11/ DK5(10)
      COMMON/POLY1 / P21(4)
      COMMON/POLY2 / P22(4)
      COMMON/POLY3 / P23(5),P33(5)
      COMMON/POLY4 / P24(5),P34(5)
C
      DIMENSION P11(4),P12(4),P13(5),P14(5)
C
      DATA AK1/0.999999974532240D+0,
     &        -0.499995525890027D+0,
     &         0.333203435554182D+0,
     &        -0.248529457735332D+0,
     &         0.191451164493502D+0,
     &        -0.137466222203386D+0,
     &         0.792107405737825D-1,
     &        -0.301109652783781D-1,
     &         0.538406198111749D-2/
C
      DATA AK2/0.999999980543793D+0,
     &        -0.999995797779624D+0,
     &         0.916516447393493D+0,
     &        -0.831229921350708D+0,
     &         0.745873737923571D+0,
     &        -0.634523908078600D+0,
     &         0.467104011423750D+0,
     &        -0.261348046799178D+0,
     &         0.936814286867420D-1,
     &        -0.156249375012462D-1/
C
      DATA AK3/9.99999989322696D-1,
     &        -1.49999722020708D+0,
     &         1.74988008499745D+0,
     &        -1.87296689068405D+0,
     &         1.91539974617231D+0,
     &        -1.85963744001295D+0,
     &         1.62987195424434D+0,
     &        -1.17982353224299D+0,
     &         6.28710122994999D-1,
     &        -2.11307487211713D-1,
     &         3.28953352932140D-2/
C
      DATA BK1/0.693147166991375D+0,
     &        -0.306850436868254D+0,
     &         0.193078041088284D+0,
     &        -0.139403892894644D+0,
     &         0.105269615988049D+0,
     &        -0.746801353858524D-1,
     &         0.427339135378207D-1,
     &        -0.161809049989783D-1,
     &         0.288664611077007D-2/
C
      DATA BK2/0.480453024731510D+0,
     &         0.480450679641120D+0,
     &        -0.519463586324817D+0,
     &         0.479285947990175D+0,
     &        -0.427765744446172D+0,
     &         0.360855321373065D+0,
     &        -0.263827078164263D+0,
     &         0.146927719341510D+0,
     &        -0.525105367350968D-1,
     &         0.874144396622167D-2/
C
      DATA CK1/-0.283822933724932D+0,
     &          0.999994319023731D+0,
     &         -0.124975762907682D+1,
     &          0.607076808008983D+0,
     &         -0.280403220046588D-1,
     &         -0.181869786537805D+0,
     &          0.532318519269331D+0,
     &         -0.107281686995035D+1,
     &          0.138194913357518D+1,
     &         -0.111100841298484D+1,
     &          0.506649587198046D+0,
     &         -0.100672390783659D+0/
C
      DATA CK2/ 0.480322239287449D+0,
     &         -0.168480825099580D+1,
     &          0.209270571620726D+1,
     &         -0.101728150275998D+1,
     &          0.160179976133047D+0,
     &         -0.351982236677917D+0,
     &          0.141033316846244D+1,
     &         -0.353343997843391D+1,
     &          0.593934696819832D+1,
     &         -0.660019784804042D+1,
     &          0.466330349413063D+1,
     &         -0.189825467489058D+1,
     &          0.339772909487512D+0/
C
      DATA CK3/-0.243948949064443D-1,
     &          0.000005136294145D+0,
     &          0.249849075518710D+0,
     &         -0.498290708990997D+0,
     &          0.354866791547134D+0,
     &         -0.522116678353452D-1,
     &         -0.648354706049337D-1,
     &          0.644165053822532D-1,
     &         -0.394927322542075D-1,
     &          0.100879370657869D-1/
C
      DATA CK4/ 0.192962504274437D+0,
     &          0.000005641557253D+0,
     &         -0.196891075399448D+1,
     &          0.392919138747074D+1,
     &         -0.290306105685546D+1,
     &          0.992890266001707D+0,
     &         -0.130026190226546D+1,
     &          0.341870577921103D+1,
     &         -0.576763902370864D+1,
     &          0.645554138192407D+1,
     &         -0.459405622046138D+1,
     &          0.188510809558304D+1,
     &         -0.340476080290674D+0/
C
      DATA CK5/-0.822467033400775D+0,
     &          0.887664705657325D-1,
     &         -0.241549406045162D-1,
     &          0.965074750946139D-2,
     &         -0.470587487919749D-2,
     &          0.246014308378549D-2,
     &         -0.116431121874067D-2,
     &          0.395705193848026D-3,
     &         -0.664699010014505D-4/
C
      DATA DK5/-0.822467033400775D+0,
     &          0.999999974532240D+0,
     &         -0.249997762945014D+0,
     &          0.111067811851394D+0,
     &         -0.621323644338330D-1,
     &          0.382902328987004D-1,
     &         -0.229110370338977D-1,
     &          0.113158200819689D-1,
     &         -0.376387065979726D-2,
     &          0.598229109013054D-3/
C
      PI = 3.141592653589793238462643D0
      ZETA2 = PI**2/6.0D0       
      ZETA3 = 1.20205690315959428540D0
      ZET2=ZETA2
      ZET3=ZETA3
      ZLI4 = FLI4(0.5D0)
      XLI4 = FLI4(0.5D0)
      D2 = DLOG(2.0D0)
      DL = DLOG(2.0D0)
      GE   = 0.57721566490153D+0
C
      ZERO=0.0D0
      ONE =1.0D0
C
C----------------------------------------------------------------------
      P11(1)=-49.0D0/36.0+ZETA2
      P11(2)=11.0D0/6.0D0
      P11(3)=-7.0D0/12.0D0
      P11(4)=1.0D0/9.0D0
C-------------------------------                       
      P21(1)=11.0D0/6.0
      P21(2)=-3.0D0
      P21(3)=3.0D0/2.0D0
      P21(4)=-1.0D0/3.0D0
C-------------------------------                       
      P12(1)=ZETA3-11.0D0/6.0*ZETA2+4.0D0/3.0D0
      P12(2)=3.0D0*ZETA2-13.0D0/4.0D0
      P12(3)=-3.0D0/2.0D0*ZETA2+5.0D0/2.0D0
      P12(4)=1.0D0/3.0D0*ZETA2-7.0D0/12.0D0
C-------------------------------                       
      P22(1)=-1.0D0
      P22(2)=5.0D0/2.0D0
      P22(3)=-2.0D0
      P22(4)=1.0D0/2.0D0
C-------------------------------                       
      P13(1)=ZETA3-2035.0D0/1728.0D0
      P13(2)=205.0D0/144.0D0
      P13(3)=-95.0D0/288.0D0
      P13(4)=43.0D0/432.0D0
      P13(5)=-1.0D0/64.0D0
C-------------------------------                       
      P23(1)=205.0D0/144.0D0
      P23(2)=-25.0D0/12.0D0
      P23(3)=23.0D0/24.0D0
      P23(4)=-13.0D0/36.0D0
      P23(5)=1.0D0/16.0D0
C-------------------------------                       
      P33(1)=-25.0D0/24.0D0
      P33(2)=2.0D0
      P33(3)=-3.0D0/2.0D0
      P33(4)=2.0D0/3.0D0
      P33(5)=-1.0D0/8.0D0
C-------------------------------                       
      P14(1)=257.D0/144.0D0-205.0D0/72.0D0*ZET2+ZET2**2
      P14(2)=-167.0D0/36.0D0+25.0D0/6.0D0*ZET2
      P14(3)=101.0D0/24.0D0-23.0D0/12.0D0*ZET2
      P14(4)=-59.0D0/36.0D0+13.0D0/18.0D0*ZET2
      P14(5)=41.0D0/144.0D0-ZET2/8.0D0
C-------------------------------                       
      P24(1)=-167.0D0/36.0D0+25.0D0/6.0D0*ZET2
      P24(2)=235.0D0/18.0D0-8.0D0*ZET2
      P24(3)=-40.0D0/3.0D0+6.0D0*ZET2
      P24(4)=109.0D0/18.0D0-8.0D0/3.0D0*ZET2
      P24(5)=-41.0D0/36.0D0+ZET2/2.0D0
C-------------------------------                       
      P34(1)=35.0D0/12.0D0
      P34(2)=-26.0D0/3.0D0
      P34(3)=19.0D0/2.0D0
      P34(4)=-14.0D0/3.0D0
      P34(5)=11.0D0/12.0D0
C----------------------------------------------------------------------
C
C >>> ACCOUNT FOR POLYNOM PARTS
C
      CK1(1)=CK1(1)+P11(1)
      CK1(2)=CK1(2)+P11(2)
      CK1(3)=CK1(3)+P11(3)
      CK1(4)=CK1(4)+P11(4)
C
      CK2(1)=CK2(1)+P12(1)
      CK2(2)=CK2(2)+P12(2)
      CK2(3)=CK2(3)+P12(3)
      CK2(4)=CK2(4)+P12(4)
C
      CK3(1)=CK3(1)+P13(1)
      CK3(2)=CK3(2)+P13(2)
      CK3(3)=CK3(3)+P13(3)
      CK3(4)=CK3(4)+P13(4)
      CK3(5)=CK3(5)+P13(5)
C
      CK4(1)=CK4(1)+P14(1)
      CK4(2)=CK4(2)+P14(2)
      CK4(3)=CK4(3)+P14(3)
      CK4(4)=CK4(4)+P14(4)
      CK4(5)=CK4(5)+P14(5)
C
C----------------------------------------------------------------------
C
      KEY = 2
      MAX = 10000
C
      IAPP=1
C
      CALL INVINI
C
      RETURN
      END
      DOUBLE PRECISION FUNCTION FLI4(X)
C     -----------------------------------
C************************************************************************
C     
C     J. BLUEMLEIN:  01.10.1999 (1.00)
C
C************************************************************************
C
C---  LI4(X) FOR -1. LE . X . LE .+1
C
C************************************************************************
C
      IMPLICIT REAL*8(A-H,O-Z)
C
      A=1D0
      F=0D0
      AN=0D0 
      TCH=1D-16  
1     AN=AN+1D0
      A=A*X
      B=A/AN**4
      F=F+B 
      IF(ABS(B)-TCH)2,2,1
2     FLI4 = F
      END



      include 'mellin.f'
      include 'COEFFHN.f'
      include 'partonvw.f'
